Hilmo_tidy: A Hilmo tidy function

Description Usage Arguments Details Examples

View source: R/Hilmo_tidy.R

Description

This function allows you to change the data from long to wide format

Usage

1
Hilmo_tidy(dataname)

Arguments

dataname

the name of your data you are working with

Details

Every row represents one patient

Examples

1

vilponk/hilmotools documentation built on March 15, 2020, 12:39 a.m.